# List of endpoints in the platform

LOGIN_ENDPOINT = None  # TODO - May be deleted in a future version
VERIFY_PASSWORD_ENDPOINT = 'password/verify'
DEPLOY_MODEL_ENDPOINT = 'models/deploy'
LIST_MODELS_ENDPOINT = 'models/list'
UNDEPLOY_MODEL_ENDPOINT = 'models/undeploy'
PREDICT_ENDPOINT = 'models/predict'
CREATE_USER_ENDPOINT = 'users/create'
DELETE_USER_ENDPOINT = 'users/delete'
NEW_API_KEY_ENDPOINT = 'users/api_key/issue'
NEW_PASSWORD_ENDPOINT = 'users/password/issue'
GET_USER_ROLE_ENDPOINT = 'users/role'
UPDATE_USER_ROLE_ENDPOINT = 'users/role'
LIST_USERS_ENDPOINT = 'users/list'
RESET_ENDPOINT = 'reset'
RESTART_JUPYTER_ENDPOINT = 'restart-jupyter'
RESOURCE_USAGE = 'system/resource-usage'
GET_VARIABLE = 'variable-store/get'
LIST_VARIABLES = 'variable-store/list'
SET_VARIABLE = 'variable-store/set'
DELETE_VARIABLE = 'variable-store/delete'
GET_PREDICTIONS = 'predictions'
LIST_PREDICTIONS_MODELS = 'predictions/models'
GET_MODEL_LOGS = 'model-logs'
OLLAMA = 'ollama'
